@@ -1,9 +1,8 @@
 # !/usr/bin/env python
+"""Command line pipes in python."""
 
 from __future__ import generator_stop
 
-from pprint import pprint
-
 import collections
 import importlib
 import io
